##  Applying and Aggregating Views
You can choose various views, similar to Reports. Views are essentially attributes or relations, which are represented through a color-coded visualization. Each view provides a unique perspective on the data, enabling the user to gain better insights. Check our [Report views documentation](https://help.sap.com/docs/leanix/ea/report-views?locale=en-US&state=PRODUCTION&version=CLOUD "Get an overview of standard report views and learn how to use custom views.") to understand the different insights you can gain from applying views.
The view toolbar at the top of the canvas becomes active whenever there is at least one fact sheet in the diagram. Select the needed view from the drop-down menu. After selecting a view, the view colors will be applied to the related fact sheets, and the view legend will be displayed above. When the diagram is saved, the view will also be stored.
In the views menu, one can also select Fact Sheet Colors, which will revert the color of the shapes to respective fact sheet type colors as defined in the Meta Model.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274ddc6b7a4410149872b2b9d085e82e_LowRes.gif)
For views on diagrams, it is possible to change the aggregation of the selected view. Aggregations can only be applied to views of fields that are either Fields on relations or Fields on related fact sheets.
By default, the aggregation configured in the meta model is used. Also, note that aggregations only apply to a set of data. If there is only one relationship to a fact sheet in the diagram, the view won't change because the resulting value is the same.
In the example below, you see the Organization Headquarter with two relations to IT Components. The view is set to Used IT Components: Technical Fit. The first IT Component’s Technical Fit is set to Unreasonable, and for the other, it is set to Adequate. Since the default aggregation is configured as Minimum, the fact sheet Headquarter gets the color that represents Unreasonable. When aggregation is set to Maximum, the fact sheet Headquarter gets the color that represents Adequate.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274663db7a441014af5282772ba83fce_LowRes.gif)
While aggregating the view, it is possible to select one specific fact sheet. When a fact sheet is selected, only relations to this fact sheet are considered for the view.
In the example below, the view Organization / Business Capabilities: Pace Layering is selected. This view uses a relation to the fact sheet type Business Capability. Therefore, you can select one of the Business Capability fact sheets. Then, using the option Select a related Business Capability, you choose a specific fact sheet. Now, the view is calculated, taking into account all relations to that particular fact sheet.
More generally, this functionality is supported for any Single Select, Double, and Integer fields on relations or fields on related fact sheets.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2743a1067a441014b6c8ab41c50a52dc_LowRes.gif)
